@@ -2,6 +2,12 @@ from utils import *
 import RPIO
 from hautomation_gpio import WrongGPIOConfiguration, USED_GPIO_LIST
 
+import logging
+from django.conf import settings
+
+logger = logging.getLogger("driver")
+logger.setLevel(settings.LOG_LEVEL)
+
 
 def set_to_output(address):
     validate_address(address)
@@ -15,7 +21,9 @@ def pl_switch(address, value):
     validate_address(address)
 
     if not is_output(address):
-        raise WrongGPIOConfiguration("GPIO%s is not OUTPUT configured" % address)
+        logger.warning("GPIO%s is not OUTPUT configured, changing it ti OUTPUT" % address)
+        set_to_output(instance.did)
+
 
     RPIO.output(address, value == "on")
 
